@@ -48,7 +48,7 @@ void ags_fx_eq10_audio_signal_real_run_inter(AgsRecall *recall);
 
 static gpointer ags_fx_eq10_audio_signal_parent_class = NULL;
 
-static const gchar *ags_fx_eq10_audio_signal_plugin_name = "ags-fx-eq10";
+const gchar *ags_fx_eq10_audio_signal_plugin_name = "ags-fx-eq10";
 
 GType
 ags_fx_eq10_audio_signal_get_type()
